extends Node2D


var height_noise: FastNoiseLite
var height_map: PackedFloat64Array


func _ready():
	_init_noise()
	_generate_height_map()
	_save_to_file()


func _init_noise():
	height_noise = FastNoiseLite.new()
	height_noise.seed = randi()
	height_noise.noise_type = FastNoiseLite.TYPE_PERLIN
	height_noise.frequency = 0.0003


func _generate_height_map():
	for y in 4096:
		for x in 4096:
			var value: float = height_noise.get_noise_2d(x, y)
			height_map.append(value)


func _save_to_file():
	var image := Image.new()
	image.create(4096, 4096, false, Image.FORMAT_RGB8)
	
	var buffer := PackedByteArray()
	buffer.resize(4096 * 4096 * 3)
	buffer = image.get_data()
	
	for y in 4096:
		for x in 4096:
			var grayscale_value = int((height_map[y * 4096 + x] + 1) * 127.5)
			
			buffer.append(grayscale_value) # Red
			buffer.append(grayscale_value) # Green
			buffer.append(grayscale_value) # Blue
	
	image.set_data(4096, 4096, false, Image.FORMAT_RGB8, buffer)
	image.save_png("res://height_map.png")
